@@ -4,7 +4,7 @@ default_config = \
 'summary_dir': 'summary',
 'model_dir': 'model',
 'distance_mode': 'L2',
-'embedding_size': 512,
+'embedding_size': -1,
 'sequence_length': 0,
 'h_channel': 8,
 'beta_ratio': 50000,
