@@ -3,14 +3,20 @@ import os
 import pandas as pd
 import math
 import numpy as np
+import dendropy
 from Bio import SeqIO
 
 def get_seq_length(args):
     backbone_seq_file = args.backbone_seq_file
+    backbone_tree_file = args.backbone_tree_file
     seq = SeqIO.to_dict(SeqIO.parse(backbone_seq_file, "fasta"))
     args.sequence_length = len(list(seq.values())[0])
+    tree = dendropy.Tree.get(path=backbone_tree_file, schema='newick')
+    num_nodes = len(tree.leaf_nodes())
+    if args.embedding_size == -1:
+        args.embedding_size = 2**math.floor(math.log2(10*num_nodes**(1/2)))
 
-def distance(nodes1, nodes2, mode):
+def distance_portion(nodes1, nodes2, mode):
     if len(nodes1.shape) == 1:
         nodes1 = nodes1.unsqueeze(0)
     if len(nodes2.shape) == 1:
@@ -22,7 +28,7 @@ def distance(nodes1, nodes2, mode):
     if mode == 'ms':
         return torch.sum((nodes1 - nodes2) ** 2, dim=-1)
     elif mode == 'L2':
-        return torch.sum((nodes1 - nodes2) ** 2, dim=-1)
+        return torch.sum((nodes1 - nodes2) ** 2, dim=-1).sqrt()
     elif mode == 'L1':
         return torch.sum(abs(nodes1 - nodes2), dim=-1)
     elif mode == 'cosine':
@@ -31,6 +37,13 @@ def distance(nodes1, nodes2, mode):
         cosine = torch.nn.functional.cosine_similarity(nodes1, nodes2, dim=-1)
         return (1 - cosine ** 2) / (cosine + 1e-9)
 
+def distance(nodes1, nodes2, mode):
+    # node1: query
+    # node2: backbone
+    dist = []
+    for i in range(math.ceil(len(nodes1) / 1000.0)):
+        dist.append(distance_portion(nodes1[i*1000: (i+1)*1000], nodes2, mode))
+    return torch.cat(dist, dim=0)
 
 def mse_loss(model_dist, true_dist, weighted_method):
     assert model_dist.shape == true_dist.shape
@@ -96,7 +109,8 @@ def save_depp_dist(model, args):
     backbone_seq_file = args.backbone_seq_file
     query_seq_file = args.query_seq_file
     dis_file_root = os.path.join(args.outdir)
-    args.distance_ratio = float(1.0 / float(args.embedding_size) / 10 * float(args.distance_alpha))
+    # args.distance_ratio = float(1.0 / float(args.embedding_size) / 10 * float(args.distance_alpha))
+    args.distance_ratio = model.hparams.distance_ratio
     if not os.path.exists(dis_file_root):
         os.makedirs(dis_file_root)
 
